@@ -40,8 +40,6 @@ from graphclass import Drawing
 
 import yaml
 
-from jinja2 import Template
-
 ID_DV = "|"
 
 class FIELD:
@@ -345,8 +343,8 @@ class ObjectModelItem:
 
         xml_tree = structure_to_xml(data_structure)
 
-        with open("query.xml", "w", encoding="utf-8") as file:
-            file.write(prettify(xml_tree.getroot()))
+        # with open("query.xml", "w", encoding="utf-8") as file:
+        #     file.write(prettify(xml_tree.getroot()))
 
         reslist = plain_query(xml_tree, query)
 
@@ -527,9 +525,6 @@ class ObjectList:
 
         return res
 
-def get_icon_path():
-    return os.path.abspath('./icons/').replace("\\", "/")
-
 def node_label(obj):
     ''' html code for node '''
     draw  = type(obj).Draw
@@ -551,7 +546,7 @@ def node_label(obj):
     if draw & DRAW.ICON:
         res = res + f'''
             <TR>
-                <TD BGCOLOR="white" PORT="p2"><IMG SRC="{get_icon_path()}/{type(obj).Icon}.png"/></TD>
+                <TD BGCOLOR="white" PORT="p2"><IMG SRC="{type(obj).Icon}"/></TD>
             </TR>
         '''
     res = res + f'''
@@ -585,7 +580,7 @@ def cluster_label(obj):
     res0 = ""
     if draw & DRAW.ICON:
         res0 = res0 + f'''
-            <TD ROWSPAN="3"><IMG SRC="{get_icon_path()}/{type(obj).Icon}.png"/></TD>
+            <TD ROWSPAN="3"><IMG SRC="{type(obj).Icon}"/></TD>
         '''
 
     if draw & DRAW.VIEW:
@@ -698,15 +693,13 @@ class ObjectModel:
             wrapper = getattr(self, name)
             res += wrapper.print()
 
-        with open("./render/print.yaml", "w") as file: file.write(res)
-
-
+        return res
 
     def load(self):
         ''' Loads model from file '''
-        if not os.path.exists("./render/" + self.path + ".xml"): return
+        if not os.path.exists(self.path): return
 
-        with open("./render/" + self.path + ".xml", 'r') as file:
+        with open(self.path, 'r') as file:
             xml_string = file.read()
         root = ET.fromstring(xml_string)
 
@@ -741,7 +734,7 @@ class ObjectModel:
 
 
         tree = prettify(root)
-        with open("./render/" + self.path + ".xml", "w") as file:
+        with open(self.path, "w") as file:
             file.write(tree)
 
     def auto_save(self):
@@ -895,17 +888,14 @@ class ObjectModel:
                         continue
                     drawing.add_link(corr.get_draw_link(self), idlink, field + "<")
 
-        # drawing.print()
+        return drawing
 
-        drawstr = drawing.draw("./render/" + self.path)
+
+    def html(self, clss_list = None):
+        return self.draw(clss_list).html("OMF")
+
+    def svg(self, clss_list = None):
+        return self.draw(clss_list).svg("OMF")
     
-        with open('./render/Y3A.svg', 'w') as file:
-            file.write(drawstr)
-
-        with open('./Y3A.j2', 'r') as file:
-            template_str = file.read()
-
-        template = Template(template_str)
-        output = template.render(content=drawstr)
-        with open('./render/Y3A.html', 'w') as f:
-            f.write(output)
+    def source(self, clss_list = None):
+        return self.draw(clss_list).source("OMF")
